@@ -301,6 +301,7 @@ class SparseFastSigmoid(torch.autograd.Function):
                 S&≈\\frac{U}{1 + k|U|}H(U-B) \\\\
                 \\frac{∂S}{∂U}&=\\begin{cases} \\frac{1}{(1+k|U|)^2} & \\text{\\rm if U > B}
                 0 & \\text{\\rm otherwise}
+                \\end{cases}
 
     :math:`k` defaults to 25, and can be modified by calling ``surrogate.SFS(slope=25)``.
     :math:`B` defaults to 1, and can be modified by calling ``surrogate.SFS(B=1)``.
@@ -313,7 +314,7 @@ class SparseFastSigmoid(torch.autograd.Function):
     def forward(ctx, input_, slope=25, B=1):
         ctx.save_for_backward(input_)
         ctx.slope = slope
-        ctx.B=B
+        ctx.B = B
         out = (input_ > 0).float()
         return out
 
@@ -321,7 +322,11 @@ class SparseFastSigmoid(torch.autograd.Function):
     def backward(ctx, grad_output):
         (input_,) = ctx.saved_tensors
         grad_input = grad_output.clone()
-        grad = grad_input / (ctx.slope * torch.abs(input_) + 1.0) ** 2 * (input_ > ctx.B).float()
+        grad = (
+            grad_input
+            / (ctx.slope * torch.abs(input_) + 1.0) ** 2
+            * (input_ > ctx.B).float()
+        )
         return grad, None, None
 
 
@@ -336,7 +341,6 @@ def SFS(slope=25, B=1):
     return inner
 
 
-
 # class InverseSpikeOperator(torch.autograd.Function):
 #     """
 #     Surrogate gradient of the Heaviside step function.
@@ -459,6 +463,5 @@ def SFS(slope=25, B=1):
 #     return inner
 
 
-
 # piecewise linear func
 # tanh surrogate func
